==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/infocapture/classes/Util/Relations.php <==
<?php
namespace Claromentis\Infocapture\Util;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] ?: array()) + array("_7f628626dd1d5" . "5c71b1fc0932ff" . "d1d2c" => base64_decode("aXNf" . "YXJy" . "YXk="), "i" . "d" => base64_decode("aWQ" . "="), "_6edacb78" . "bd55c5015" . "af27c8ac1" . "fcd9af" => base64_decode("bWV0aG9kX2V4aX" . "N0cw=="), "_0eae80f3e4f2" . "1fcc67ca8ca95" . "c6cc91f" => base64_decode("R2V0UH" . "JvcGVy" . "dHk="), "_ea8229a121285ee649a72fd880bac3" . "9b" => base64_decode("YXJyYX" . "lfZmls" . "dGVy"));
use Claromentis\Core\Repository\RepositoryItem;
use Claromentis\Infocapture\Repository\InfocaptureRepositoryInterface;






class Relations
{
    
    
    
    
    
    
    
    
    
    public static function GetFor(array $_bcf97e0ae4e759f267ed02765fb52ae9, InfocaptureRepositoryInterface $_2f38dc687f8aa379aefb57f3ac9620fe, string $_df5a829bb6f8ccbb208e4b53124dbbf2, $_3b0b788afd03419829052390c6bd8208 = '') : array
    {
        
        
        $_bcf97e0ae4e759f267ed02765fb52ae9 = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_ea8229a12" . "1285ee649a" . "72fd880bac" . "39b"]((array) $_bcf97e0ae4e759f267ed02765fb52ae9);
        
        
        if (empty($_bcf97e0ae4e759f267ed02765fb52ae9)) {
            return array();
        }
        return $_2f38dc687f8aa379aefb57f3ac9620fe->findWhereIn($_df5a829bb6f8ccbb208e4b53124dbbf2, $_bcf97e0ae4e759f267ed02765fb52ae9, $_3b0b788afd03419829052390c6bd8208);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Match(array $_7be0fe72d1d4f4705351e229d138bccd, array $_98121e94e148d73a15700996ba4d7a53, string $_df5a829bb6f8ccbb208e4b53124dbbf2, string $_50304948b9940e3756a41b1f5ef8b829)
    {
        
        
        if (empty($_7be0fe72d1d4f4705351e229d138bccd)) {
            return array();
        }
        
        
        
        
        
        $_3d7361f0fc29b20400e3529f3f15eba0 = array();
        $_1d3c9b5bc98fd0e6ce39ca7bdee50a14 = array();
        
        
        
        
        
        
        foreach ($_7be0fe72d1d4f4705351e229d138bccd as $_568fcb2872723a3ebac6afca64f9238e) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_6edacb78bd5" . "5c5015af27c8" . "ac1fcd9af"]($_568fcb2872723a3ebac6afca64f9238e, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_0eae80f3e4f21fcc" . "67ca8ca95c6cc91f"])) {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_568fcb2872723a3ebac6afca64f9238e->GetProperty($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["i" . "d"]);
            } else {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_568fcb2872723a3ebac6afca64f9238e->GetValue($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["i" . "d"]);
            }
            $_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a] = $_568fcb2872723a3ebac6afca64f9238e;
            $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a] = array();
        }
        
        
        
        
        foreach ($_98121e94e148d73a15700996ba4d7a53 as $_1bd6e5a007d5639e67837f0567493081) {
            if ($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_7f628626dd1d55c71" . "b1fc0932ffd1d2c"]($_1bd6e5a007d5639e67837f0567493081)) {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_1bd6e5a007d5639e67837f0567493081[$_df5a829bb6f8ccbb208e4b53124dbbf2];
            } else {
                if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_6edacb78bd55c" . "5015af27c8ac1f" . "cd9af"]($_1bd6e5a007d5639e67837f0567493081, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_0eae80f3e4f21f" . "cc67ca8ca95c6cc" . "91f"])) {
                    $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_1bd6e5a007d5639e67837f0567493081->GetProperty($_df5a829bb6f8ccbb208e4b53124dbbf2);
                } else {
                    $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_1bd6e5a007d5639e67837f0567493081->GetValue($_df5a829bb6f8ccbb208e4b53124dbbf2);
                }
            }
            
            
            if (!isset($_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a])) {
                continue;
            }
            $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a][] = $_1bd6e5a007d5639e67837f0567493081;
        }
        
        
        
        
        foreach ($_3d7361f0fc29b20400e3529f3f15eba0 as $_6e38cb9e043a07cd69a1711a6704c62a => $_568fcb2872723a3ebac6afca64f9238e) {
            
            
            $_5dfe54e15693106ff9a6ec257db06b29 =& $_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a];
            
            
            $_98121e94e148d73a15700996ba4d7a53 = $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a];
            
            
            $_5dfe54e15693106ff9a6ec257db06b29->{$_50304948b9940e3756a41b1f5ef8b829}($_98121e94e148d73a15700996ba4d7a53);
        }
        return $_3d7361f0fc29b20400e3529f3f15eba0;
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function LoadFor(array $_7be0fe72d1d4f4705351e229d138bccd, InfocaptureRepositoryInterface $_2f38dc687f8aa379aefb57f3ac9620fe, string $_df5a829bb6f8ccbb208e4b53124dbbf2, string $_50304948b9940e3756a41b1f5ef8b829, string $_3b0b788afd03419829052390c6bd8208 = '') : array
    {
        
        
        if (empty($_7be0fe72d1d4f4705351e229d138bccd)) {
            return array();
        }
        
        
        $_bcf97e0ae4e759f267ed02765fb52ae9 = array();
        foreach ($_7be0fe72d1d4f4705351e229d138bccd as $_568fcb2872723a3ebac6afca64f9238e) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_6edacb78bd55c5015af27c8" . "ac1fcd9af"]($_568fcb2872723a3ebac6afca64f9238e, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_0eae80f3e4f21fcc67ca8ca95c6cc91" . "f"])) {
                $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_568fcb2872723a3ebac6afca64f9238e->GetProperty($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["i" . "d"]);
            } else {
                $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_568fcb2872723a3ebac6afca64f9238e->GetValue($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["i" . "d"]);
            }
        }
        
        
        $_98121e94e148d73a15700996ba4d7a53 = static::GetFor($_bcf97e0ae4e759f267ed02765fb52ae9, $_2f38dc687f8aa379aefb57f3ac9620fe, $_df5a829bb6f8ccbb208e4b53124dbbf2, $_3b0b788afd03419829052390c6bd8208);
        
        
        return static::Match($_7be0fe72d1d4f4705351e229d138bccd, $_98121e94e148d73a15700996ba4d7a53, $_df5a829bb6f8ccbb208e4b53124dbbf2, $_50304948b9940e3756a41b1f5ef8b829);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/infocapture/classes/Util/Relations.php <==
<?php
namespace Claromentis\Infocapture\Util;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"] ?: array()) + array("_7f628626dd" . "1d55c71b1fc" . "0932ffd1d2c" => base64_decode("aXNfYXJyYX" . "k="), "_ea8229a121285ee649" . "a72fd880bac39b" => base64_decode("YXJyYXlfZml" . "sdGVy"), "_0eae80f3e4f21fcc67ca8c" . "a95c6cc91f" => base64_decode("R2V0UHJvcGVyd" . "Hk="), "i" . "d" => base64_decode("aWQ" . "="), "_6edacb78bd55c5" . "015af27c8ac1fcd" . "9af" => base64_decode("bWV0aG9kX2V" . "4aXN0cw=="));
use Claromentis\Core\Repository\RepositoryItem;
use Claromentis\Infocapture\Repository\InfocaptureRepositoryInterface;






class Relations
{
    
    
    
    
    
    
    
    
    
    public static function GetFor(array $_bcf97e0ae4e759f267ed02765fb52ae9, InfocaptureRepositoryInterface $_2f38dc687f8aa379aefb57f3ac9620fe, string $_df5a829bb6f8ccbb208e4b53124dbbf2, $_3b0b788afd03419829052390c6bd8208 = '') : array
    {
        
        
        $_bcf97e0ae4e759f267ed02765fb52ae9 = $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_ea8229a121285ee6" . "49a72fd880bac39b"]((array) $_bcf97e0ae4e759f267ed02765fb52ae9);
        
        
        if (empty($_bcf97e0ae4e759f267ed02765fb52ae9)) {
            return array();
        }
        return $_2f38dc687f8aa379aefb57f3ac9620fe->findWhereIn($_df5a829bb6f8ccbb208e4b53124dbbf2, $_bcf97e0ae4e759f267ed02765fb52ae9, $_3b0b788afd03419829052390c6bd8208);
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function Match(array $_7be0fe72d1d4f4705351e229d138bccd, array $_98121e94e148d73a15700996ba4d7a53, string $_df5a829bb6f8ccbb208e4b53124dbbf2, string $_50304948b9940e3756a41b1f5ef8b829)
    {
        
        
        if (empty($_7be0fe72d1d4f4705351e229d138bccd)) {
            return array();
        }
        
        
        
        
        
        $_3d7361f0fc29b20400e3529f3f15eba0 = array();
        $_1d3c9b5bc98fd0e6ce39ca7bdee50a14 = array();
        
        
        
        
        
        
        foreach ($_7be0fe72d1d4f4705351e229d138bccd as $_568fcb2872723a3ebac6afca64f9238e) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_6edacb78bd55c501" . "5af27c8ac1fcd9af"]($_568fcb2872723a3ebac6afca64f9238e, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_0eae80f3e4f21fcc67ca8ca95" . "c6cc91f"])) {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_568fcb2872723a3ebac6afca64f9238e->GetProperty($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["i" . "d"]);
            } else {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_568fcb2872723a3ebac6afca64f9238e->GetValue($GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["i" . "d"]);
            }
            $_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a] = $_568fcb2872723a3ebac6afca64f9238e;
            $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a] = array();
        }
        
        
        
        
        foreach ($_98121e94e148d73a15700996ba4d7a53 as $_1bd6e5a007d5639e67837f0567493081) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_7f628626dd1d55c71b1fc0932" . "ffd1d2c"]($_1bd6e5a007d5639e67837f0567493081)) {
                $_6e38cb9e043a07cd69a1711a6704c62a = $_1bd6e5a007d5639e67837f0567493081[$_df5a829bb6f8ccbb208e4b53124dbbf2];
            } else {
                if ($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_6edacb78bd55c5015af27c8ac" . "1fcd9af"]($_1bd6e5a007d5639e67837f0567493081, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_0eae80f3e4f21fcc67ca8ca9" . "5c6cc91f"])) {
                    $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_1bd6e5a007d5639e67837f0567493081->GetProperty($_df5a829bb6f8ccbb208e4b53124dbbf2);
                } else {
                    $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_1bd6e5a007d5639e67837f0567493081->GetValue($_df5a829bb6f8ccbb208e4b53124dbbf2);
                }
            }
            
            
            if (!isset($_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a])) {
                continue;
            }
            $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a][] = $_1bd6e5a007d5639e67837f0567493081;
        }
        
        
        
        
        foreach ($_3d7361f0fc29b20400e3529f3f15eba0 as $_6e38cb9e043a07cd69a1711a6704c62a => $_568fcb2872723a3ebac6afca64f9238e) {
            
            
            $_5dfe54e15693106ff9a6ec257db06b29 =& $_3d7361f0fc29b20400e3529f3f15eba0[$_6e38cb9e043a07cd69a1711a6704c62a];
            
            
            $_98121e94e148d73a15700996ba4d7a53 = $_1d3c9b5bc98fd0e6ce39ca7bdee50a14[$_6e38cb9e043a07cd69a1711a6704c62a];
            
            
            $_5dfe54e15693106ff9a6ec257db06b29->{$_50304948b9940e3756a41b1f5ef8b829}($_98121e94e148d73a15700996ba4d7a53);
        }
        return $_3d7361f0fc29b20400e3529f3f15eba0;
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function LoadFor(array $_7be0fe72d1d4f4705351e229d138bccd, InfocaptureRepositoryInterface $_2f38dc687f8aa379aefb57f3ac9620fe, string $_df5a829bb6f8ccbb208e4b53124dbbf2, string $_50304948b9940e3756a41b1f5ef8b829, string $_3b0b788afd03419829052390c6bd8208 = '') : array
    {
        
        
        if (empty($_7be0fe72d1d4f4705351e229d138bccd)) {
            return array();
        }
        
        
        $_bcf97e0ae4e759f267ed02765fb52ae9 = array();
        foreach ($_7be0fe72d1d4f4705351e229d138bccd as $_568fcb2872723a3ebac6afca64f9238e) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_6edacb78bd55c5015" . "af27c8ac1fcd9af"]($_568fcb2872723a3ebac6afca64f9238e, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_0eae80f3e4f21fcc67ca8" . "ca95c6cc91f"])) {
                $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_568fcb2872723a3ebac6afca64f9238e->GetProperty($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["i" . "d"]);
            } else {
                $_bcf97e0ae4e759f267ed02765fb52ae9[] = $_568fcb2872723a3ebac6afca64f9238e->GetValue($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["i" . "d"]);
            }
        }
        
        
        $_98121e94e148d73a15700996ba4d7a53 = static::GetFor($_bcf97e0ae4e759f267ed02765fb52ae9, $_2f38dc687f8aa379aefb57f3ac9620fe, $_df5a829bb6f8ccbb208e4b53124dbbf2, $_3b0b788afd03419829052390c6bd8208);
        
        
        return static::Match($_7be0fe72d1d4f4705351e229d138bccd, $_98121e94e148d73a15700996ba4d7a53, $_df5a829bb6f8ccbb208e4b53124dbbf2, $_50304948b9940e3756a41b1f5ef8b829);
    }
}
